@@ -116,15 +116,15 @@ class _MatcherContext:
 
 class Matcher(ABC):
     """The baseclass for all Matchers."""
-    def __init__(self, override_name: Optional[str] = None) -> None:
+    def __init__(self) -> None:
         super().__init__()
-        self.__name = override_name if override_name is not None else self.__class__.__name__
+        self.__name = self.__class__.__name__
         self.__state = _MatcherState()
         self.__context: Optional[_MatcherContext] = None
 
     def as_(self, type_: Type[T]) -> T:
         """To make matchers pass type checking."""
-        return self  # type: ignore
+        return self  # type: ignore[return-value]
 
     @final
     def nested_match(
@@ -150,6 +150,10 @@ class Matcher(ABC):
         else:
             return matcher == other
 
+    @final
+    def _override_name(self, name: str) -> None:
+        self.__name = name
+
     @final
     def _reset_nested_failures(
         self,
